Method: GoodData::Metric.all
- Defined in:
- lib/gooddata/models/metadata/metric.rb
.all(options = { :client => GoodData.connection, :project => GoodData.project }) ⇒ Array<GoodData::MdObject> | Array<Hash>
Method intended to get all objects of that type in a specified project
to pull in full objects. This is desirable from the usability POV but unfortunately has negative impact on performance so it is not the default.
31 32 33 |
# File 'lib/gooddata/models/metadata/metric.rb', line 31 def all( = { :client => GoodData.connection, :project => GoodData.project }) query('metric', Metric, ) end |