Method: GoodData::Metric#contain_value?

Defined in:
lib/gooddata/models/metadata/metric.rb

#contain_value?(label, value) ⇒ Boolean

Checks that the expression contains certain element of an attribute. The value is looked up through given label.

Parameters:

  • label (GoodData::Label)

    Label though which the value is looked up

  • value (String)

    Value that will be looked up through the label.

Returns:

  • (Boolean)


159
160
161
162
# File 'lib/gooddata/models/metadata/metric.rb', line 159

def contain_value?(label, value)
  uri = label.find_value_uri(value)
  contain?(uri)
end