Method: GoodData::Metric#pretty_expression

Defined in:
lib/gooddata/models/metadata/metric.rb

#pretty_expressionString

Looks up the readable values of the objects used inside of MAQL epxpressions. Labels and elements titles are based on the primary label.

Returns:

  • (String)

    Ther resulting MAQL like expression



201
202
203
# File 'lib/gooddata/models/metadata/metric.rb', line 201

def pretty_expression
  SmallGoodZilla.pretty_print(expression, client: client, project: project)
end