Method: GoodData::Project#am_i_admin?

Defined in:
lib/gooddata/models/project.rb

#am_i_admin?Boolean

Returns an indication whether current user is admin in this project

Returns:

  • (Boolean)

    True if user has admin role in the project, false otherwise.



809
810
811
# File 'lib/gooddata/models/project.rb', line 809

def am_i_admin?
  user_has_role?(client.user, 'admin')
end