Method: GoodData::Dashboard.all

Defined in:
lib/gooddata/models/metadata/dashboard.rb

.all(options = { :client => GoodData.connection, :project => GoodData.project }) ⇒ Array<GoodData::MdObject> | Array<Hash>

Method intended to get all objects of that type in a specified project

decide to pull in full objects. This is desirable from the usability POV but unfortunately has negative impact on performance so it is not the default.

Parameters:

  • options (Hash) (defaults to: { :client => GoodData.connection, :project => GoodData.project })

    the options hash

Options Hash (options):

  • :full (Boolean)

    if passed true the subclass can

Returns:

  • (Array<GoodData::MdObject> | Array<Hash>)

    Return the appropriate metadata objects or their representation



54
55
56
# File 'lib/gooddata/models/metadata/dashboard.rb', line 54

def all(options = { :client => GoodData.connection, :project => GoodData.project })
  query('projectDashboard', Dashboard, options)
end