Method: GoodData::Dashboard.all
- Defined in:
- lib/gooddata/models/metadata/dashboard.rb
.all(options = { :client => GoodData.connection, :project => GoodData.project }) ⇒ Array<GoodData::MdObject> | Array<Hash>
Method intended to get all objects of that type in a specified project
decide to pull in full objects. This is desirable from the usability POV but unfortunately has negative impact on performance so it is not the default.
54 55 56 |
# File 'lib/gooddata/models/metadata/dashboard.rb', line 54 def all( = { :client => GoodData.connection, :project => GoodData.project }) query('projectDashboard', Dashboard, ) end |